import { Grid } from "@mui/material";
import { memo, useMemo } from "react";
import CalendarStandartCell from "../CalendarStandartCell.js/CalendarStandartCell";
import CalendarTask from "../CalendarTask/CalendarTask";

const CalendarRowDay = ({xs, hoursInDay, createTaskInCellHandler, currentTask, handleOpen, modal, setCurrentTask, year, month, tasks, day, hourFormat}) => {

  const hours = useMemo(()=>{ 
    return hoursInDay.map((hour)=>parseInt(hour.split(':')[0]))},
  [hoursInDay])

  const availableTasks = useMemo(() => {
    const tasksInDay = tasks.filter((task)=> {
    if (year === task.infoForCell.startYear) {
      if (month + 1 === task.infoForCell.startMonth) {
        if (day.dayNumber === task.infoForCell.startDay) {
              return task
          } else {return false}   
        } else {return false}   
      } else {return false}      
    })
    return tasksInDay
  }, [tasks, month, year, day.dayNumber])

  const sortedTasks = useMemo(() => {
    if (availableTasks.length) {
      const newSortedArr = [...availableTasks].sort(function(a,b){
        const durattionFirstDate = new Date(a.dateTimeDue).getTime() - new Date(a.dateTimeStart).getTime()
        const durattionSecondDate = new Date(b.dateTimeDue).getTime() - new Date(b.dateTimeStart).getTime()
        return durattionSecondDate - durattionFirstDate;
      })
      return newSortedArr
    }
  }, [availableTasks])

  const linesInDay = useMemo(() => {
    let hourDiff
    let hourDiffEnd
    const lines = []
    if (hourFormat) {
      hourDiff = 1
      hourDiffEnd = 0
    } else {
      hourDiff = 2
      hourDiffEnd = 1
    }
    if (availableTasks.length) {
      lines.push(hoursInDay.map((hour)=>parseInt(hour.split(':')[0])))
      for (let k = 0; k < sortedTasks.length; k++) {
        let skipLine = false
          for (let j = 0; j < lines.length; j++) {
            const line = lines[j]
            const task = sortedTasks[k]
            if (skipLine) {
              skipLine = false
              break;
            }
            for (let i = 0; i < line.length; i++) {
              const hour = hours[i]
              let havePlace = true
              if (((task.infoForCell.endHour <= hour || task.infoForCell.startHour  <= hour) && (task.infoForCell.endHour > hour))  
              || (!hourFormat && task.infoForCell.startHour >= hour  && task.infoForCell.endHour < hour + hourDiff)
              || (!hourFormat && task.infoForCell.startHour === hour + hourDiffEnd && task.infoForCell.endHour > hour)
              || (task.infoForCell.endMinute <= 59 && task.infoForCell.endHour === hour)) {
                if (!isNaN(line[i])) {
                  for (let a = 0; a < hours.length; a++) {
                    const hour = hours[a]
                    if ((task.infoForCell.endMinute === 59 && task.infoForCell.endHour === hour + hourDiffEnd) || (!hourFormat && task.infoForCell.endMinute === 59 && task.infoForCell.endHour === hour)) {
                      if (isNaN(line[a])) {
                        havePlace = false
                        break;
                      }
                    }
                  }
                  if (!havePlace) {
                    havePlace = true  
                    break;
                  }
                  line[i] += `-${k}`
                  if ((task.infoForCell.endMinute === 59 && task.infoForCell.endHour === hour + hourDiffEnd) || (!hourFormat && task.infoForCell.endMinute === 59 && task.infoForCell.endHour === hour)) {
                    skipLine = true
                    break;
                  }
                } else {
                    if (j + 1 === lines.length) {
                      lines.push(hoursInDay.map((hour)=>parseInt(hour.split(':')[0])))
                    }
                    break;
                }
              } 
            }
          }
      }
    }
    return lines
  }, [availableTasks.length, hourFormat, hours, hoursInDay, sortedTasks])

  return <>
      <Grid 
        container
        item
        xs={10.8}
        align='center'
        >
          {hoursInDay.map((hour, i)=>{
            const linesForCell = []
            if (linesInDay?.length) {
              for (let j = 0; j < linesInDay.length; j++) {
                linesForCell.push(linesInDay[j][i])
              }
            }
            return (
              <CalendarStandartCell
                key={i} 
                item xs={xs}
                createTaskInCellHandler={createTaskInCellHandler}
                hours={hour}
                dayNumber={day.dayNumber}
                currentTask={currentTask}
                handleOpen={handleOpen}
                modal={modal}
                >
                  <CalendarTask
                    setCurrentTask={setCurrentTask}
                    hours={hour}
                    modal={modal}
                    hourFormat={hourFormat}
                    handleOpen={handleOpen}
                    currentTask={currentTask}
                    linesForCell={linesForCell.length ? linesForCell : null}
                    sortedTasks={sortedTasks}
                  />               
              </CalendarStandartCell>
              ) 
            })}
        </Grid>
    </>
};

export default memo(CalendarRowDay);