import { Grid} from "@mui/material";
import React, { memo} from "react";


const TaskDefault = ({task, onClickTaskHandler}) => {
  return(<Grid  
        sx={{ height: '30px', backgroundColor: 'lightgreen', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', borderRadius: '10px', margin: '5px 10px', textAlign: 'left'}} 
        onClick={onClickTaskHandler}
        >
          <span>
            {task.title}
          </span>
    </Grid>)
}

const TaskWithNoStartAndAllEnd = ({task, onClickTaskHandler}) => {
  return(<Grid
        sx={{height: '30px', backgroundColor: 'lightgreen', whiteSpace: 'nowrap', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', borderTopLeftRadius: '10px', borderBottomLeftRadius: '10px', margin:"5px -1px 5px 10px", position:'relative', textAlign: 'left'}} 
        onClick={onClickTaskHandler}
        >
          <span>
            {task.title}
          </span>
    </Grid>)
}
const TaskWithAllStartAndNoEnd = ({onClickTaskHandler}) => {
  return(<Grid  
        sx={{height: '30px',backgroundColor: 'lightgreen', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', borderTopRightRadius: '10px', borderBottomRightRadius: '10px', margin:"5px 10px 5px -1px"}} 
        onClick={onClickTaskHandler}
        >
          <span>
            	&#8291;
          </span>
    </Grid>)
}
const TaskWithAllStartAndAllEnd = ({onClickTaskHandler}) => {
  return(<Grid  
        sx={{height: '30px', backgroundColor: 'lightgreen', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px',  borderBottom: '1px solid rgb(29, 161, 51)', margin:"5px -1px"}} 
        onClick={onClickTaskHandler}
        >
          <span>
            	&#8291;
          </span>
    </Grid>)
}

const Empty = () => {
  return (<Grid  
      sx={{height: '30px', backgroundColor: 'rgb(0,0,0,0)', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', padding: '5px', margin:"5px -1px"}} 
      >
        <span>
            &#8291;
        </span>
  </Grid>)
}




const CalendarTask = ({hours, setCurrentTask, hourFormat, handleOpen, currentTask, linesForCell, sortedTasks}) => {

  const hour = parseInt(hours.split(':')[0])

  const onClickTaskHandler = (e, task) => {
    e.stopPropagation(); 
    setCurrentTask(task); 
    handleOpen(e)
  }

  return (<> 
      {linesForCell?.length ? linesForCell.map((line, i)=>
      {
        if (isNaN(line)) {
          const task = sortedTasks[line.split('-')[1]]
          if ((hourFormat && task.infoForCell.endHour > hour && task.infoForCell.startHour === hour) 
              || (!hourFormat && (task.infoForCell.endHour - 1 > hour)
                  && (task.infoForCell.startHour === hour || task.infoForCell.startHour === hour +1))) {
            return (<TaskWithNoStartAndAllEnd
                key={task.id}
                task={task}
                onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
              />)
          }
          if ((hourFormat && task.infoForCell.startHour < hour && task.infoForCell.endHour > hour) 
              || (!hourFormat && task.infoForCell.startHour < hour && task.infoForCell.endHour > hour + 1)) {
            return (<TaskWithAllStartAndAllEnd
              key={task.id}
              onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
            />)
          }
          if (task.infoForCell.endMinute === 59 && task.infoForCell.startHour < hour) {
            return (
              <TaskWithAllStartAndNoEnd
                key={task.id}
                onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
              />)
          }
          return (
            <TaskDefault
              key={task.id}
              task={task}
              onClickTaskHandler={(e)=>{onClickTaskHandler(e, task)}}
            />
          )
        } else {
          return (
            <Empty
              
            />
          )
        }
        }
          
      ) 
      : null}
  </>)
};

export default memo(CalendarTask);